<?php

/**
 * Define this Export UI plugin.
 */
$plugin = array(
  'schema' => 'sharedblocks',  // As defined in hook_schema().
  'access' => 'subscribe to blocks',  // Define a permission users must have to access these pages.

  // Define the menu item.
  'menu' => array(
    'menu item' => 'subscribe',
    'menu prefix' => 'admin/structure/sharedblocks',
    'menu title' => 'Subscribed Blocks',
    'menu description' => 'Administer Shared Block subscriptions.',
  ),

  // Define user interface texts.
  'title singular' => t('subscription'),
  'title plural' => t('subscriptions'),
  'title singular proper' => t('Shared Block subscription'),
  'title plural proper' => t('Shared Block subscriptions'),

  // Define the names of the functions that provide the add/edit forms.
  'form' => array(
    'settings' => 'sharedblocks_ctools_export_ui_form',
    // 'submit' and 'validate' are also valid callbacks.
  ),
);

/**
 * Implements HOOK_ctools_export_ui_form()
 */
function sharedblocks_ctools_export_ui_form(&$form, &$form_state) {
  $subscription = $form_state['item'];
  $form['url'] = array(
    '#type' => 'textfield',
    '#title' => t('Subscribe URL'),
    '#default_value' => $subscription->url,
    '#description' => t('The URL to the block you wish to subscribe to, supplied by publishing site.'),
    '#required' => TRUE,
  );
  $interval_options = drupal_map_assoc(array(60, 300, 600, 1200, 1800, 3600, 10800, 21600, 32400, 43200, 86400, 172800, 259200, 604800, 1209600, 2419200, 4838400, 9676800), 'format_interval');
  $default_interval = 3600;
  $form['update_interval'] = array(
    '#type' => 'select',
    '#title' => t('Refresh rate'),
    '#options' => $interval_options,
    '#description' => t("How frequently should this block's content be updated? Note that this can only run as often as cron runs."),
    '#default_value' => empty($subscription->update_interval) ? $default_interval : $subscription->update_interval,
  );
}


/**
 * Validate a subscribed block
 */
function sharedblocks_ctools_export_ui_form_validate($form, &$form_state) {
  $values = $form_state['values'];
  // Check for machine-readable name.
  if (preg_match('/[^0-9A-Za-z_]/', $values['name'])) {
    form_set_error('name', t('Your machine-readable name must be alphanumeric and underscore characters only.'));
  }

  // Check that the URL is valid
  $block_data = _sharedblocks_fetch_url($values['url']);
  if (empty($block_data)) {
    form_set_error('url', t('Block information not received: Please check your URL.'));
  }

}


/**
 * Handle submission of a new subscribed block
 */
function sharedblocks_ctools_export_ui_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  // Fetch the block from the publishing site.
  $block_data = _sharedblocks_fetch_url($values['url']);
  // Prep our values for the database.
  if (!empty($block_data['subject'])) {
    $form_state['values']['description'] = $block_data['subject'];
  }

  // Update the cached data for the block, if an existing block is being edited.
  $cache_id = 'sharedblocks:' . $values['name'];
  $block_cache = cache_get($cache_id, 'cache_block');
  if (is_object($block_cache)) {
    dsm('flush teh cache');
    sharedblocks_cache_refresh($values['name']);
  }
}
